OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Eingebettete Nachricht %s",
    "Important mail" : "Wichtige E-Mail",
    "No message found yet" : "Keine Nachrichten gefunden",
    "Set up an account" : "Konto einrichten",
    "Unread mail" : "Ungelesene E-Mail",
    "Important" : "Wichtig",
    "Work" : "Arbeit",
    "Personal" : "Persönlich",
    "To Do" : "Offen",
    "Later" : "Später",
    "Mail" : "E-Mail",
    "You are reaching your mailbox quota limit for {account_email}" : "Du erreichst die Grenze deines Postfach-Kontingents für {account_email}",
    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "Du nutzt derzeit {percentage} deines Postfachspeichers. Bitte schaffe etwas Platz, indem du nicht benötigte E-Mails löscht.",
    "Mails" : "E-Mails",
    "💌 A mail app for Nextcloud" : "💌 Eine E-Mail-App für Nextcloud",
    "Your session has expired. The page will be reloaded." : "Deine Sitzung ist abgelaufen. Seite wird neu geladen.",
    "Drafts are saved in:" : "Entwürfe werden gespeichert in:",
    "Sent messages are saved in:" : "Gesendete Nachrichten werden gespeichert in:",
    "Deleted messages are moved in:" : "Gelöschte Nachrichten werden verschoben nach:",
    "Archived messages are moved in:" : "Archivierte Nachrichten werden verschoben nach:",
    "Snoozed messages are moved in:" : "Zurückgestellte Nachrichten werden verschoben nach:",
    "Junk messages are saved in:" : "Spam-Nachrichten werden gespeichert in:",
    "Auto" : "Automatisch",
    "Name" : "Name",
    "Mail address" : "E-Mail-Adresse",
    "name@example.org" : "name@beispiel.de",
    "Please enter an email of the format name@example.com" : "Bitte gib eine E-Mail-Adresse im Format name@beispiel.de ein",
    "Password" : "Passwort",
    "Manual" : "Manuell",
    "IMAP Settings" : "IMAP-Einstellungen",
    "IMAP Host" : "IMAP-Host",
    "IMAP Security" : "IMAP-Sicherheit",
    "None" : "Keine",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-Port",
    "IMAP User" : "IMAP-Benutzer",
    "IMAP Password" : "IMAP-Passwort",
    "SMTP Settings" : "SMTP-Einstellungen",
    "SMTP Host" : "SMTP-Host",
    "SMTP Security" : "SMTP-Sicherheit",
    "SMTP Port" : "SMTP-Port",
    "SMTP User" : "SMTP-Benutzer",
    "SMTP Password" : "SMTP-Passwort",
    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "Damit das Google-Konto mit dieser App funktioniert, musst du die Zwei-Faktor-Authentifizierung für Google aktivieren und ein App-Passwort erstellen.",
    "Connecting" : "Verbinde",
    "Reconnect Google account" : "Google-Konto wiederverbinden",
    "Sign in with Google" : "Mit Google anmelden",
    "Save" : "Speichern",
    "Connect" : "Verbinden",
    "Looking up configuration" : "Konfiguration ansehen",
    "Checking mail host connectivity" : "Konnektivität des E-Mail Servers wird geprüft",
    "Configuration discovery failed. Please use the manual settings" : "Konfigurationserkennung ist fehlgeschlagen. Bitte verwende die manuellen Einstellungen.",
    "Password required" : "Passwort erforderlich",
    "Testing authentication" : "Prüfe Authentifizierung",
    "Awaiting user consent" : "Warte auf Zustimmung des Benutzers",
    "Account created. Please follow the pop-up instructions to link your Google account" : "Konto erstellt. Bitte befolge die Pop-up-Anweisungen, um dein Google-Konto zu verknüpfen",
    "Loading account" : "Lade Konto",
    "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "Konto aktualisiert. Bitte befolge die Pop-up-Anweisungen, um dein Google-Konto erneut zu verbinden",
    "Account updated" : "Konto aktualisiert",
    "IMAP server is not reachable" : "IMAP-Server ist nicht erreichbar.",
    "SMTP server is not reachable" : "SMTP-Server ist nicht erreichbar.",
    "IMAP username or password is wrong" : "Falscher IMAP-Benutzername oder Passwort.",
    "SMTP username or password is wrong" : "SMTP-Benutzername oder Passwort ist falsch.",
    "IMAP connection failed" : "IMAP-Verbindung fehlgeschlagen",
    "SMTP connection failed" : "SMTP-Verbindung fehlgeschlagen",
    "Authorization pop-up closed" : "Anmeldungs-Pop-up wurde geschlossen",
    "Configuration discovery temporarily not available. Please try again later." : "Konfigurationserkennung vorübergehend nicht verfügbar. Bitte versuche es später noch einmal.",
    "There was an error while setting up your account" : "Bei der Einrichtung deines Kontos ist ein Fehler aufgetreten.",
    "Account settings" : "Konto-Einstellungen",
    "Aliases" : "Aliasse",
    "Alias to S/MIME certificate mapping" : "Alias einerm S/MIME-Zertifikat zuordnen",
    "Signature" : "Signatur",
    "A signature is added to the text of new messages and replies." : "Dem Text der Nachrichten und Antworten wird eine Signatur hinzugefügt.",
    "Writing mode" : "Schreibmodus",
    "Preferred writing mode for new messages and replies." : "Bevorzugter Schreibmodus für neue Nachrichten und Antworten.",
    "Default folders" : "Standardordner",
    "The folders to use for drafts, sent messages, deleted messages, archived messages and junk messages." : "Die Ordner, die für Entwürfe, gesendete Nachrichten, gelöschte Nachrichten, archivierte Nachrichten und Spam-Nachrichten verwendet werden sollen.",
    "Automatic trash deletion" : "Automatische Papierkorblöschung",
    "Days after which messages in Trash will automatically be deleted:" : "Tage, nach denen Nachrichten im Papierkorb automatisch gelöscht werden:",
    "Autoresponder" : "Automatische Antworten",
    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Automatisierte Antwort auf eingehende Nachrichten. Wenn dir jemand mehrere Nachrichten schickt, wird diese automatische Antwort höchstens einmal alle 4 Tage gesendet.",
    "Please connect to a sieve server first." : "Bitte stelle zunächst eine Verbindung zu einem Sieve-Server her.",
    "Sieve filter rules" : "Sieve-Filterregeln",
    "Trusted senders" : "Vertrauenswürdige Absender",
    "Mail server" : "Mail-Server",
    "Sieve filter server" : "Sieve-Filterserver",
    "Mailbox search" : "Postfach durchsuchen",
    "Update alias" : "Alias aktualisieren",
    "Rename alias" : "Alias umbenennen",
    "Show update alias form" : "Update-Alias-Formular anzeigen",
    "Delete alias" : "Alias löschen",
    "Go back" : "Zurück",
    "Change name" : "Name ändern",
    "Email address" : "E-Mail-Adresse",
    "Add alias" : "Alias hinzufügen",
    "Create alias" : "Alias erstellen",
    "Cancel" : "Abbrechen",
    "Add mail account" : "E-Mail-Konto hinzufügen",
    "Use Gravatar and favicon avatars" : "Gravatar- und Favicon-Avatare verwenden",
    "Register as application for mail links" : "Als Anwendung für Mail-Links registrieren",
    "Show keyboard shortcuts" : "Tastaturkürzel anzeigen",
    "Manage S/MIME certificates" : "S/MIME Zertifikate verwalten",
    "Newest" : "Neueste",
    "Oldest" : "Älteste",
    "Looking for a way to encrypt your emails?" : "Suchst du nach einer Möglichkeit, deine E-Mails zu verschlüsseln?",
    "Install Mailvelope browser extension here" : "Die Mailvelope-Browsererweiterung hier installieren",
    "Search in the body of messages in priority Inbox" : "Im Nachrichtentext im Prioritäts-Posteingang suchen",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Erlaube der App, Daten über deine Interaktionen zu sammeln. Basierend auf diesen Daten passt sich die App an deine Vorlieben an. Die Daten werden nur lokal gespeichert.",
    "Put my text to the bottom of a reply instead of on top of it." : "Füge meinen Text am Ende einer Antwort anstatt darüber. ",
    "Automatically classify importance of new email" : "Automatisches Einordnen der Wichtigkeit neuer E-Mails",
    "Could not update preference" : "Voreinstellung konnte nicht aktualisieren werden",
    "Select an alias" : "Alias wählen",
    "Update Certificate" : "Zertifikat aktualisieren",
    "No certificate" : "Kein Zertifikat",
    "Certificate updated" : "Zertifikat aktualisiert",
    "Could not update certificate" : "Zertifikat konnte nicht aktualisiert werden",
    "{commonName} - Valid until {expiryDate}" : "{commonName} - Gültig bis {expiryDate}",
    "From" : "Von",
    "Select account" : "Konto auswählen",
    "To" : "An",
    "Contact or email address …" : "Kontakt oder E-Mailadresse",
    "Toggle recipients list mode" : "Empfängerlisten-Modus umschalten",
    "Cc" : "Cc",
    "Bcc" : "Bcc",
    "No contacts found." : "Keine Kontakte gefunden.",
    "Subject" : "Betreff",
    "Subject …" : "Betreff …",
    "This message came from a noreply address so your reply will probably not be read." : "Diese Nachricht stammt von einer Niachtantworten-Adresse, daher wird deine Antwort wahrscheinlich nicht gelesen werden.",
    "The following recipients do not have a S/MIME certificate: {recipients}." : "Die folgenden Empfänger haben kein S/MIME-Zertifikat: {recipients}.",
    "The following recipients do not have a PGP key: {recipients}." : "Die folgenden Empfänger haben keinen PGP-Schlüssel: {recipients}.",
    "Write message …" : "Nachricht verfassen …",
    "Saving draft …" : "Speichere Entwurf …",
    "Error saving draft" : "Fehler beim Speichern des Entwurfs",
    "Draft saved" : "Entwurf gespeichert",
    "Save draft" : "Entwurf speichern",
    "Discard & close draft" : "Entwurf verwerfen & schließen",
    "Upload attachment" : "Anhang hochladen",
    "Add attachment from Files" : "Anhang von \"Dateien\" hinzufügen",
    "Smart picker" : "Intelligente Auswahl",
    "Send later" : "Später senden",
    "Enable formatting" : "Formatierung aktivieren",
    "Disable formatting" : "Formatierung deaktivieren",
    "Request a read receipt" : "Eine Bestätigung anfordern",
    "Sign message with S/MIME" : "Nachricht mit S/MIME signieren",
    "Encrypt message with S/MIME" : "Nachricht mit S/MIME verschlüsseln",
    "Encrypt message with Mailvelope" : "Nachricht mit Mailvelope verschlüsseln",
    "Send now" : "Jetzt senden",
    "Tomorrow morning" : "Morgen Vormittag",
    "Tomorrow afternoon" : "Morgen Nachmittag",
    "Monday morning" : "Montag Vormittag",
    "Custom date and time" : "Benutzerspezifisches Datum und Zeit",
    "Enter a date" : "Datum eingeben",
    "Add share link from {productName} Files" : "Freigabelink aus {productName}-Dateien hinzufügen",
    "Encrypt with S/MIME and send later" : "Mit S/MIME verschlüsseln und später versenden",
    "Encrypt with S/MIME and send" : "Mit S/MIME verschlüsseln und versenden",
    "Encrypt with Mailvelope and send later" : "Mit Mailvelope verschlüsseln und später versenden",
    "Encrypt with Mailvelope and send" : "Mit Mailvelope verschlüsseln und versenden",
    "Send" : "Senden",
    "Message {id} could not be found" : "Nachricht {id} konnte nicht gefunden werden",
    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Mit S/MIME signieren oder verschlüsseln wurde ausgewählt, aber wir haben kein Zertifikat für den ausgewählten Alias. Die Nachricht wird nicht signiert oder verschlüsselt.",
    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Vorhandene Formatierungen (z. B. fett, kursiv, unterstrichen oder eingefügte Bilder) werden entfernt.",
    "Turn off formatting" : "Formatierung ausschalten",
    "Turn off and remove formatting" : "Formatierung ausschalten und entfernen",
    "Keep formatting" : "Formatierung beibehalten",
    "Choose a file to add as attachment" : "Wähle eine Datei, die als Anhang angefügt werden soll",
    "Choose a file to share as a link" : "Datei auswählen welche als Link geteilt wird",
    "_{count} attachment_::_{count} attachments_" : ["{count} Anhang","{count} Anhänge"],
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Der Anhang überschreitet die zulässige Anhangsgröße von {size}. Bitte teilen Sie die Dateien stattdessen über einen Link.","Die Anhänge überschreiten die zulässige Anhangsgröße von {size}. Bitte teile die Dateien stattdessen über einen Link."],
    "Expand composer" : "Erstellungsbereich erweitern",
    "Close composer" : "Erstellungsbereich schließen",
    "Untitled message" : "Nachricht ohne Titel",
    "Confirm" : "Bestätigen",
    "The tag will be deleted from all messages." : "Das Schlagwort wird aus allen Nachrichten gelöscht.",
    "Tag: {name} deleted" : "Schlagwort: {name} gelöscht",
    "An error occurred, unable to delete the tag." : "Es ist ein Fehler aufgetreten, das Schlagwort konnte nicht gelöscht werden.",
    "Plain text" : "Klartext",
    "Rich text" : "Rich-Text",
    "No messages in this mailbox" : "Keine Nachrichten in diesem Postfach",
    "No messages" : "Keine Nachrichten",
    "Draft: " : "Entwurf:",
    "Encrypted message" : "Verschlüsselte Nachricht",
    "This message is unread" : "Diese Nachricht ist ungelesen",
    "Unfavorite" : "Von Favoriten entfernen",
    "Favorite" : "Favorit",
    "Unread" : "Ungelesen",
    "Read" : "Gelesen",
    "Unimportant" : "Unwichtig",
    "Mark not spam" : "Als „Kein Spam“ markieren",
    "Mark as spam" : "Als Spam markieren",
    "Unselect" : "Abwählen",
    "Select" : "Auswählen",
    "Edit tags" : "Schlagworte bearbeiten",
    "Snooze" : "Zurückstellen",
    "Unsnooze" : "Zurückstellung aufheben",
    "Move thread" : "Unterhaltung verschieben",
    "Archive thread" : "Thema archivieren",
    "Delete thread" : "Unterhaltung löschen",
    "More actions" : "Weitere Aktionen",
    "Back" : "Zurück",
    "Set custom snooze" : "Zurückstellen benutzerdefiniert setzen",
    "Edit as new message" : "Als neue Nachricht bearbeiten",
    "Create event" : "Termin erstellen",
    "Create task" : "Aufgabe erstellen",
    "Download message" : "Nachricht herunterladen",
    "Blind copy recipients only" : "Nur BCC-Empfänger",
    "No subject" : "Kein Betreff",
    "Set reminder for later today" : "Erinnerung für nachher erstellen",
    "Set reminder for tomorrow" : "Erinnerung für morgen erstellen",
    "Set reminder for this weekend" : "Erinnerung für dieses Wochenende erstellen",
    "Set reminder for next week" : "Erinnerung für nächste Woche erstellen",
    "No trash mailbox configured" : "Kein Papierkorb-Postfach konfiguriert",
    "Could not delete message" : "Nachricht konnte nicht gelöscht werden",
    "Could not archive message" : "Nachricht konnte nicht archiviert werden",
    "Thread was snoozed" : "Unterhaltung wurde zurückgestellt",
    "Could not snooze thread" : "Unterhaltung konnte nicht zurückgestellt werden",
    "Thread was unsnoozed" : "Zurückstellung der Unterhaltung aufgehoben",
    "Could not unsnooze thread" : "Zurückstellung der Unterhaltung konnte nicht aufgehoben werden",
    "Forward" : "Weiterleiten",
    "Load more" : "Mehr laden",
    "_Mark {number} unread_::_Mark {number} unread_" : ["{number} als ungelesen markieren","{number} als ungelesen markieren"],
    "_Mark {number} read_::_Mark {number} read_" : ["{number} als gelesen markieren","{number} als gelesen markieren"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["{number} als wichtig markieren","{number} als wichtig markieren"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["{number} als unwichtig markieren","{number} als unwichtig markieren"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["{number} nicht favorisieren","{number} nicht favorisieren"],
    "_Favorite {number}_::_Favorite {number}_" : ["{number} favorisieren","{number} favorisieren"],
    "_Unselect {number}_::_Unselect {number}_" : ["{number} nicht auswählen","{number} nicht auswählen"],
    "_Move {number} thread_::_Move {number} threads_" : ["{number} Unterhaltung verschieben","{number} Unterhaltungen verschieben"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Weiterleiten {number} als Anhang","Weiterleiten {number} als Anhang"],
    "_Delete {number} thread_::_Delete {number} threads_" : ["{number} Unterhaltung gelöscht","{number} Unterhaltungen löschen"],
    "Report this bug" : "Diesen Bug melden",
    "All day" : "Ganztägig",
    "Create" : "Erstellen",
    "Event created" : "Termin wurde erstellt",
    "Could not create event" : "Termin konnte nicht erstellt werden",
    "You accepted this invitation" : "Du hast diese Einladung akzeptiert.",
    "You tentatively accepted this invitation" : "Du hast diese Einladung vorläufig angenommen.",
    "You declined this invitation" : "Du hast die Einladung abgelehnt.",
    "You already reacted to this invitation" : "Du hast bereits auf diese Einladung reagiert.",
    "You have been invited to an event" : "Du wurdest zu einem Termin eingeladen.",
    "This event was cancelled" : "Dieser Termin wurde abgesagt.",
    "Save to" : "Speichern",
    "Comment" : "Kommentar",
    "Accept" : "Annehmen",
    "Decline" : "Ablehnen",
    "Tentatively accept" : "Vorläufig angenommen",
    "More options" : "Weitere Optionen",
    "This event is in the past." : "Dieser Termin liegt in der Vergangenheit.",
    "This event was updated" : "Dieser Termin wurde aktualisiert.",
    "{attendeeName} accepted your invitation" : "{attendeeName} hat deine Einladung angenommen.",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} hat deine Einladung als vorläufig angenommen.",
    "{attendeeName} declined your invitation" : "{attendeeName} hat deine Einladung abgelehnt.",
    "{attendeeName} reacted to your invitation" : "{attendeeName}  hat auf deine Einladung reagiert.",
    "Failed to save your participation status" : "Dein Teilnahmestatus konnte nicht gespeichert werden.",
    "Could not open mailbox" : "E-Mail-Postfach konnte nicht geöffnet werden",
    "Loading messages …" : "Lade Nachrichten …",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Deine Nachrichten werden indiziert. Dies kann bei größeren E-Mail-Postfächern etwas länger dauern.",
    "To archive a message please configure an archive mailbox in account settings" : "Um eine Nachricht zu archivieren, bitte ein Archivpostfach in den Kontoeinstellungen einrichten",
    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Du hast nicht die Berechtigung, diese Nachricht in den Archivordner zu verschieben und/oder diese Nachricht aus dem aktuellen Ordner zu löschen",
    "Choose target mailbox" : "Zielpostfach auswählen",
    "No more submailboxes in here" : "Keine Unter-Postfächer vorhanden",
    "Choose" : "Auswählen",
    "Important info" : "Wichtige Information",
    "Other" : "Andere",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Nachrichten werden automatisch als wichtig markiert, je nachdem, mit welchen Nachrichten du interagiert, oder als wichtig markiert hast. Am Anfang musst du möglicherweise die Wichtigkeit manuell ändern, um das System anzulernen, aber es wird sich mit der Zeit verbessern.",
    "The sender of this message has asked to be notified when you read this message." : "Der Absender dieser Nachricht hat darum gebeten, benachrichtigt zu werden, wenn du diese Nachricht liest.",
    "Notify the sender" : "Absender benachrichtigen",
    "You sent a read confirmation to the sender of this message." : "Du hast dem Absender dieser Nachricht eine Lesebestätigung gesendet.",
    "Could not send mdn" : "Konnte mdn nicht senden",
    "Reply all" : "Allen antworten",
    "Reply" : "Antworten",
    "Reply to sender only" : "Nur dem Absender antworten",
    "Move message" : "Nachricht verschieben",
    "Forward message as attachment" : "Nachricht als Anhang weiterleiten",
    "View source" : "Quelle ansehen",
    "Download thread data for debugging" : "Thread-Daten zum Debuggen herunterladen",
    "Message was snoozed" : "Nachricht wurde zurückgestellt",
    "Could not snooze message" : "Nachricht konnte nicht zurückgestellt werden",
    "Message was unsnoozed" : "Zurückstellung der Nachricht wurde aufgehoben",
    "Could not unsnooze message" : "Zurückstellung der Nachricht konnte nicht aufgehoben werden",
    "Message body" : "Nachrichtentext",
    "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!" : "Warnung: Die S/MIME-Signatur dieser Nachricht ist nicht bestätigt. Der Absender gibt sich möglicherweise als jemand anderes aus!",
    "Import into calendar" : "In Kalender importieren",
    "Download attachment" : "Anhang herunterladen",
    "Save to Files" : "Unter Dateien speichern",
    "Unnamed" : "Unbenannt",
    "Embedded message" : "Eingebettete Nachricht",
    "Next week – {timeLocale}" : "Nächste Woche – {timeLocale}",
    "Choose a folder to store the attachment in" : "Ordner zum Speichern des Anhangs auswählen",
    "calendar imported" : "Kalender importiert",
    "View fewer attachments" : "Weniger Anhänge anzeigen",
    "Save all to Files" : "Alles unter Dateien sichern",
    "Download Zip" : "ZIP herunterladen",
    "Choose a folder to store the attachments in" : "Ordner zum Speichern des Anhangs auswählen",
    "_View {count} more attachment_::_View {count} more attachments_" : ["{count} weiteren Anhange anzeigen","{count} weitere Anhänge anzeigen"],
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Diese Nachricht wurde mit PGP verschlüsselt. Installiere Mailvelope um sie zu entschlüsseln.",
    "The images have been blocked to protect your privacy." : "Die Bilder wurden blockiert, um deine Privatsphäre zu schützen.",
    "Show images" : "Bilder anzeigen",
    "Show images temporarily" : "Bilder temporär anzeigen",
    "Always show images from {sender}" : "Bilder von {sender} immer anzeigen",
    "Always show images from {domain}" : "Bilder von {domain} immer anzeigen",
    "Message frame" : "Nachrichtenrahmen",
    "Quoted text" : "Zitierter Text",
    "Move" : "Verschieben",
    "Moving" : "Verschiebe",
    "Moving thread" : "Verschiebe Unterhaltung",
    "Moving message" : "Verschiebe Nachricht",
    "Mail settings" : "Mail-Einstellungen",
    "Provisioned account is disabled" : "Bereitgestelltes Konto ist deaktiviert.",
    "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Bitte melde dich mit einem Passwort an, um dieses Konto zu aktivieren. Die aktuelle Sitzung verwendet eine passwortlose Authentifizierung, z. B. SSO oder WebAuthn.",
    "Quota" : "Kontingent",
    "Show only subscribed mailboxes" : "Nur abonnierte Postfächer anzeigen",
    "Add mailbox" : "Postfach hinzufügen",
    "Mailbox name" : "Postfachname",
    "Saving" : "Speichere",
    "Move up" : "Nach oben verschieben",
    "Move down" : "Nach unten verschieben",
    "Remove account" : "Konto löschen",
    "Loading …" : "Lade …",
    "Not supported by the server" : "Wird vom Server nicht unterstützt",
    "{usage} of {limit} used" : "{usage} von {limit} genutzt",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Das Konto für {email} und zwischengespeicherte E-Mail-Daten werden aus Nextcloud entfernt, jedoch nicht von deinem E-Mail-Provider.",
    "Remove account {email}" : "Konto {email} löschen",
    "Remove {email}" : "{email} löschen",
    "Show all subscribed mailboxes" : "Alle abonnierten Postfächer anzeigen",
    "Show all mailboxes" : "Alle Postfächer anzeigen",
    "Collapse mailboxes" : "Postfächer einklappen",
    "Mark all as read" : "Alles als gelesen markieren",
    "Mark all messages of this mailbox as read" : "Alle Nachrichten in diesem Postfach als gelesen markieren",
    "Add submailbox" : "Unter-Postfach hinzufügen",
    "Edit name" : "Name bearbeiten",
    "Move mailbox" : "Postfach verschieben",
    "Clear cache" : "Cache löschen",
    "Clear locally cached data, in case there are issues with synchronization." : "Lösche lokal zwischengespeicherte Daten, falls es Probleme mit der Synchronisierung gibt.",
    "Subscribed" : "Abonniert",
    "Sync in background" : "Im Hintergrund synchronisieren",
    "Clear mailbox" : "Postfach leeren",
    "Delete mailbox" : "Postfach löschen",
    "All messages in mailbox will be deleted." : "Alle Nachrichten im Postfach werden gelöscht.",
    "Clear mailbox {name}" : "Postfach {name} leeren",
    "The mailbox and all messages in it will be deleted." : "Das Postfach und alle Nachrichten werden gelöscht.",
    "Delete mailbox {name}" : "Postfach {name} löschen",
    "An error occurred, unable to rename the mailbox." : "Es ist ein Fehler aufgetreten, die Mailbox konnte nicht umbenannt werden.",
    "_{total} message_::_{total} messages_" : ["{total} Nachricht","{total} Nachrichten"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} ungelesene von {total}","{unread} ungelesene von {total}"],
    "Outbox" : "Postausgang",
    "New message" : "Neue Nachricht",
    "Refresh" : "Aktualisieren",
    "Error sending your message" : "Fehler beim Senden der Nachricht",
    "Retry" : "Erneut versuchen",
    "Uploading attachments …" : "Lade Anhänge hoch …",
    "Sending …" : "Sende …",
    "Warning sending your message" : "Warnung beim Senden der Nachricht",
    "Send anyway" : "Dennoch senden",
    "Minimize composer" : "Erstellungsbereich minimieren",
    "Edit message" : "Nachricht bearbeiten",
    "Draft" : "Entwurf",
    "Message saved" : "Nachricht gespeichert",
    "Failed to save message" : "Fehler beim Speichern der Nachricht",
    "Failed to save draft" : "Fehler beim Speichern des Entwurfs",
    "attachment" : "Anhang",
    "attached" : "angehängt",
    "No sent mailbox configured. Please pick one in the account settings." : "Keine Postfach für gesendete Nachrichten konfiguriert. Bitte wähle eines in den Kontoeinstellungen aus.",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Du bist im Begriff, an viele Empfänger in den Feldern \"An\" und/oder \"Cc\" zu schreiben. Benutze das Feld \"Bcc\", um die Empfängeradressen zu verbergen.",
    "You mentioned an attachment. Did you forget to add it?" : "Du hast einen Anhang erwähnt. Hast du vergessen ihn hinzuzufügen?",
    "Message discarded" : "Nachricht verworfen",
    "Could not discard message" : "Nachricht konnte nicht verworfen werden",
    "Welcome to {cloudName} Mail" : "Willkommen zu {cloudName} Mail",
    "Autoresponder off" : "Automatische Antworten nicht senden",
    "Autoresponder on" : "Automatische Antworten senden",
    "First day" : "Erster Tag",
    "Last day (optional)" : "Letzter Tag (optional)",
    "${subject} will be replaced with the subject of the message you are responding to" : "${subject} wird durch den Betreff der Nachricht ersetzt, auf die du antwortest.",
    "Message" : "Nachricht",
    "Oh Snap!" : "Hoppla!",
    "Save autoresponder" : "Automatische Antworten speichern",
    "Could not open outbox" : "Postausgang konnte nicht geöffnet werden",
    "Pending or not sent messages will show up here" : "Noch ausstehende oder nicht gesendete Nachrichten werden hier angezeigt",
    "Delete" : "Löschen",
    "Message could not be sent" : "Nachricht konnte nicht gesendet werden",
    "Message deleted" : "Nachricht gelöscht",
    "Contacts with this address" : "Kontakte mit dieser E-Mail Adresse",
    "Add to Contact" : "Zu Kontakt hinzufügen",
    "New Contact" : "Neuer Kontakt",
    "Copy to clipboard" : "In die Zwischenablage kopieren",
    "Contact name …" : "Kontakt-Name …",
    "Add" : "Hinzufügen",
    "Copied email address to clipboard" : "E-Mail-Adresse in die Zwischenablage kopiert",
    "Could not copy email address to clipboard" : "E-Mail-Adresse konnte nicht in die Zwischenablage kopiert werden",
    "Search in mailbox" : "Im Postfach suchen",
    "Close" : "Schließen",
    "Search parameters" : "Suchparameter",
    "Search subject" : "Thema durchsuchen",
    "Body" : "Inhalt",
    "Search body" : "Nachrichtentext durchsuchen",
    "Pick a start date" : "Startdatum wählen",
    "Pick an end date" : "Enddatum wählen",
    "Select senders" : "Absender wählen",
    "Select recipients" : "Empfänger wählen",
    "Select CC recipients" : "CC-Empfänger wählen",
    "Select BCC recipients" : "BCC-Empfänger wählen",
    "Tags" : "Schlagworte",
    "Select tags" : "Schlagworte auswählen",
    "Marked as" : "Markiert als",
    "Has attachments" : "Hat Anhänge",
    "Clear" : "Löschen",
    "Search" : "Suchen",
    "Date" : "Datum",
    "Enable mail body search" : "Durchsuchen des Nachrichtentextes aktivieren",
    "Disabled" : "Deaktiviert",
    "Enabled" : "Aktiviert",
    "Sieve Host" : "Sieve-Host",
    "Sieve Security" : "Sieve-Sicherheit",
    "Sieve Port" : "Sieve-Port",
    "Sieve Credentials" : "Sieve-Anmeldeinformationen",
    "IMAP Credentials" : "IMAP-Anmeldeinformationen",
    "Custom" : "Benutzerdefiniert",
    "Sieve User" : "Sieve-Benutzer",
    "Sieve Password" : "Sieve-Passwort",
    "Save sieve settings" : "Sieve-Einstellungen speichern",
    "Save sieve script" : "Sieve-Skript speichern",
    "The syntax seems to be incorrect:" : "Die Syntax scheint falsch zu sein:",
    "This weekend – {timeLocale}" : "Dieses Wochenende – {timeLocale}",
    "Signature …" : "Signatur …",
    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Deine Signatur ist größer als 2 MB. Dies kann die Leistung deines Editors beeinträchtigen.",
    "Save signature" : "Signatur speichern",
    "Place signature above quoted text" : "Signatur über dem zitierten Text platzieren",
    "Edit name or color" : "Name oder Farbe bearbeiten",
    "Delete tag" : "Schlagwort löschen",
    "Saving new tag name …" : "Speichere neues Schlagwort …",
    "Set tag" : "Schlagwort setzen",
    "Unset tag" : "Schlagwort entfernen",
    "An error occurred, unable to rename the tag." : "Es ist ein Fehler aufgetreten. Das Schlagwort konnte nicht umbenannt werden.",
    "Add default tags" : "Standard-Schlagworte hinzufügen",
    "Add tag" : "Schlagwort hinzufügen",
    "Saving tag …" : "Speichere Schlagwort …",
    "Tag name is a hidden system tag" : "Name des Schlagworts ist ein verstecktes System-Schlagwort.",
    "Tag already exists" : "Schlagwort ist bereits vorhanden",
    "An error occurred, unable to create the tag." : "Es ist ein Fehler aufgetreten. Das Schlagwort konnte nicht erstellt werden.",
    "Select calendar" : "Kalender auswählen",
    "No calendars with task list support" : "Keine Kalender mit Unterstützung für Aufgabenlisten",
    "Task created" : "Aufgabe erstellt",
    "Could not create task" : "Aufgabe konnte nicht erstellt werden",
    "Loading thread" : "Thema wird geladen",
    "Not found" : "Nicht gefunden",
    "Summarizing thread failed." : "Zusammenfassen der Unterhaltung ist fehlgeschlagen.",
    "Could not load your message thread" : "Nachrichtenverlauf konnte nicht geöffnet werden",
    "The thread doesn't exist or has been deleted" : "Der Thread existiert nicht oder wurde gelöscht.",
    "Unsubscribe" : "Abmelden",
    "Mark as unfavorite" : "Als nicht favorisiert markieren",
    "Mark as favorite" : "Als favorisiert markieren",
    "Mark as unread" : "Als ungelesen markieren",
    "Mark as read" : "Als gelesen markieren",
    "Archive message" : "Nachricht archivieren",
    "Delete message" : "Nachricht löschen",
    "Message source" : "Nachrichtenquelle",
    "Unsubscribe via link" : "Per Link abmelden",
    "Unsubscribing will stop all messages from the mailing list {sender}" : "Die Abmeldung stoppt alle Nachrichten von der Mailingliste {sender}.",
    "Send unsubscribe email" : "Abmelde-E-Mail senden",
    "Unsubscribe via email" : "Per E-Mail abmelden",
    "Encrypted & verified " : "Veschlüsselt und überprüft",
    "Signature verified" : "Signatur überprüft",
    "Signature unverified " : "Signatur nicht überprüft",
    "This message was encrypted by the sender before it was sent." : "Diese Nachricht wurde vom Absender vor der Versendung verschlüsselt.",
    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Diese Nachricht enthält eine geprüfte digitale S/MIME-Signatur. Die Nachricht wurde seit dem Senden nicht verändert.",
    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Diese Nachricht enthält eine ungeprüfte digitale S/MIME-Signatur. Unter Umständen wurde die Nachricht seit dem Senden verändert oder dem Zertifikat des Absenders wird nicht vertraut.",
    "Unsubscribe request sent" : "Anfrage zum Abmelden gesendet",
    "Could not unsubscribe from mailing list" : "Abmeldung von der Mailingliste fehlgeschlagen",
    "Go to latest message" : "Zur ältesten Nachricht springen",
    "Go to newest message" : "Zur neuesten Nachricht springen",
    "Thread Summary" : "Zusammenfassung der Unterhaltung",
    "{name} Assistant" : "{name} Assistent",
    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "Deaktiviere die Aufbewahrung im Papierkorb, indem du das Feld leer lässt oder auf 0 setzt. Es werden nur Mails verarbeitet, die nach der Aktivierung der Aufbewahrung im Papierkorb gelöscht wurden.",
    "Remove" : "Entfernen",
    "No senders are trusted at the moment." : "Derzeit sind keine Absender vertrauenswürdig.",
    "Could not remove trusted sender {sender}" : "Vertrauenswürdiger Absender konnte nicht entfernt werden {sender}",
    "individual" : "individuell",
    "domain" : "Domain",
    "(organizer)" : "(Organisator)",
    "Untitled event" : "Unbenannter Termin",
    "Import into {calendar}" : "In {calendar} importieren",
    "Event imported into {calendar}" : "Termin importiert in {calendar}",
    "Airplane" : "Flugzeug",
    "Reservation {id}" : "Reservierung {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Flug {flightNr} von {depAirport} nach {arrAirport}",
    "Train" : "Zug",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} von {depStation} nach {arrStation}",
    "Train from {depStation} to {arrStation}" : "Zug von {depStation} nach {arrStation}",
    "Mail app" : "Mail App",
    "The mail app allows users to read mails on their IMAP accounts." : "Die Mail-App ermöglicht Benutzern E-Mails von ihren IMAP-Konten zu lesen.",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Hier findest du instanzweite Einstellungen. Benutzerspezifische Einstellungen finden sich in der App selbst (linke untere Ecke).",
    "Account provisioning" : "Kontenbereitstellung",
    "A provisioning configuration will provision all accounts with a matching email address." : "Eine Bereitstellungskonfiguration stellt alle Konten mit einer übereinstimmenden E-Mail-Adresse bereit.",
    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "Die Verwendung von Platzhaltern (*) im Feld der Bereitstellungsdomäne, erstellt eine Konfiguration, die für alle Benutzer gilt, sofern sie nicht mit einer anderen Konfiguration übereinstimmen.",
    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "Der Bereitstellungsmechanismus priorisiert bestimmte Domänenkonfigurationen gegenüber der Platzhalterdomänenkonfiguration.",
    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "Sollte eine neue übereinstimmende Konfiguration gefunden werden, nachdem der Benutzer bereits mit einer anderen Konfiguration bereitgestellt wurde, hat die neue Konfiguration Vorrang und der Benutzer wird mit der Konfiguration erneut bereitgestellt.",
    "There can only be one configuration per domain and only one wildcard domain configuration." : "Es kann nur eine Konfiguration pro Domäne und nur eine Platzhalter-Domänenkonfiguration geben.",
    "These settings can be used in conjunction with each other." : "Diese Einstellungen können in Verbindung miteinander verwendet werden. ",
    "If you only want to provision one domain for all users, use the wildcard (*)." : "Wenn du nur eine Domäne für alle Benutzer bereitstellen möchtest, verwende den Platzhalter (*).",
    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "Diese Einstellung ist nur dann sinnvoll, wenn du dasselbe Benutzer-Backend für deine Nextcloud und den Mailserver deiner Organisation verwendest.",
    "Provisioning Configurations" : "Bereitstellungseinrichtung",
    "Add new config" : "Neue Einstellungen hinzufügen",
    "Provision all accounts" : "Alle Konten bereitstellen",
    "Allow additional mail accounts" : "Zusätzliche E-Mail-Konten zulassen",
    "Allow additional Mail accounts from User Settings" : "Zusätzliche E-Mail-Konten in den Benutzereinstellungen zulassen",
    "Enable thread summary" : "Zusammenfassung der Unterhaltung aktivieren",
    "Enable thread summaries" : "Zusammenfassungen der Unterhaltungen aktivieren",
    "Anti Spam Service" : "Anti-Spam-Dienst",
    "You can set up an anti spam service email address here." : "Hier kannst du eine E-Mail-Adresse für einen Anti-Spam-Dienst einrichten.",
    "Any email that is marked as spam will be sent to the anti spam service." : "Jede als Spam markierte E-Mail wird an den Anti-Spam-Dienst weitergeleitet.",
    "Gmail integration" : "Gmail-Einbindung",
    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Google Mail ermöglicht Benutzern den Zugriff auf ihre E-Mails über IMAP. Aus Sicherheitsgründen ist dieser Zugriff nur mit einer OAuth-2.0-Verbindung oder Google-Konten möglich, die Zwei-Faktor-Authentifizierung und App-Passwörter verwenden.",
    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Du musst eine neue Client-ID für eine \"Webanwendung\" in der Google Cloud-Konsole registrieren. Füge die URL {url} als autorisierten Weiterleitungs-URI hinzu.",
    "Microsoft integration" : "Microsoft-Integration",
    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Microsoft ermöglicht Benutzern den Zugriff auf ihre E-Mails über IMAP. Aus Sicherheitsgründen ist dieser Zugriff nur mit einer OAuth 2.0 Verbindung möglich.",
    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "Du musst eine neue App im Microsoft Azure Active Directory-Portal registrieren. Füge die URL {url} als Weiterleitungs-URI hinzu.",
    "Successfully updated config for \"{domain}\"" : "Einstellungen erfolgreich für \"{domain}\" aktualisiert",
    "Error saving config" : "Fehler beim Speichern der Einstellungen",
    "Saved config for \"{domain}\"" : "Einstellungen für \"{domain}\" gespeichert",
    "Could not save provisioning setting" : "Einstellungen für die Bereitstellung konnten nicht gespeichert werden",
    "There was an error when provisioning accounts." : "Beim Bereitstellen von Konten ist ein Fehler aufgetreten.",
    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "Konten für \"{domain}\" erfolgreich gelöscht und aufgehoben",
    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Fehler beim Löschen und Aufheben der Bereitstellung von Konten für \"{domain}\"",
    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["{count} Konto erfolgreich bereitgestellt.","{count} Konten erfolgreich bereitgestellt."],
    "Anti Spam" : "Anti-Spam",
    "Add the email address of your anti spam report service here." : "Füge hier die E-Mail-Adresse deines Anti-Spam-Dienstes hinzu.",
    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "Bei Verwendung dieser Einstellung wird eine Berichts-E-Mail an den SPAM-Berichtsserver gesendet, sobald ein Benutzer auf \"Als Spam markieren\" klickt.",
    "The original message will be attached as a \"message/rfc822\" attachment." : "Die Originalnachricht wird als \"message/rfc822\"-Anhang angehängt.",
    "\"Mark as Spam\" Email Address" : "\"Als Spam markieren\" E-Mail-Adresse",
    "\"Mark Not Junk\" Email Address" : "\"Nicht als Junk markieren\" E-Mail-Adresse",
    "Reset" : "Zurücksetzen",
    "Successfully set up anti spam email addresses" : "Erfolgreich Anti-Spam-E-Mail-Adressen eingerichtet",
    "Error saving anti spam email addresses" : "Fehler beim Speichern der Anti-Spam-E-Mail-Adressen",
    "Successfully deleted anti spam reporting email" : "Anti-Spam-Berichts-E-Mail erfolgreich gelöscht",
    "Error deleting anti spam reporting email" : "Fehler beim Löschen der Anti-Spam-Berichts-E-Mail",
    "Client ID" : "Client-ID",
    "Client secret" : "Geheime Zeichenkette des Clients",
    "Unlink" : "Verknüpfung aufheben",
    "Google integration configured" : "Google-Einbindung konfiguriert",
    "Could not configure Google integration" : "Google-Einbindung konnte nicht konfiguriert werden.",
    "Google integration unlinked" : "Verknüpfung mit Google-Einbindung wurde aufgehoben.",
    "Could not unlink Google integration" : "Verknüpfung mit der Google-Einbindung konnte nicht aufgehoben werden.",
    "Tenant ID (optional)" : "Tenant-ID (optional)",
    "Microsoft integration configured" : "Microsoft-Integration eingerichtet",
    "Could not configure Microsoft integration" : "Die Microsoft-Integration konnte nicht eingerichtet werden",
    "Microsoft integration unlinked" : "Verknüpfung mit Microsoft-Integration entfernt",
    "Could not unlink Microsoft integration" : "Die Verknüpfung mit der Microsoft-Integration konnte nicht entfernt werden",
    "Domain Match: {provisioningDomain}" : "Übereinstimmung der Domain: {provisioningDomain}",
    "Email: {email}" : "E-Mail: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} auf {host}:{port} ({ssl}-Verschlüsslung)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} auf {host}:{port} ({ssl}-Verschlüsslung)",
    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} auf {host}:{port} ({ssl} encryption)",
    "Configuration for \"{provisioningDomain}\"" : "Einstellungen für \"{provisioningDomain}\"",
    "General" : "Allgemein",
    "Provisioning domain" : "Domain für die Bereitstellung",
    "Email address template" : "Adressvorlage für E-Mails",
    "IMAP" : "IMAP",
    "User" : "Benutzer",
    "Host" : "Host",
    "Port" : "Port",
    "SMTP" : "SMTP",
    "Master password" : "Masterpasswort",
    "Use master password" : "Masterpasswort benutzen",
    "Sieve" : "Sieve",
    "Enable sieve integration" : "Sieve-Einbindung aktivieren",
    "LDAP aliases integration" : "LDAP-Alias-Integration",
    "Enable LDAP aliases integration" : "LDAP-Alias-Integration aktivieren",
    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "Die LDAP-Alias-Integration liest ein Attribut vom eingerichteten LDAP-Verzeichnis um E-Mail-Aliase bereitzustellen.",
    "LDAP attribute for aliases" : "LDAP-Attribut für Alias",
    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Ein Attribut mit mehreren Werten, um E-Mail-Aliasse bereitzustellen. Für jeden Wert wird ein Alias erstellt. Aliasse, die in Nextcloud, aber nicht im LDAP-Verzeichnis existieren, werden gelöscht.",
    "Save Config" : "Einstellungen speichern",
    "Unprovision & Delete Config" : "Bereitstellung aufheben und Einstellungen löschen",
    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% und %EMAIL% werden durch die UID und E-Mail-Adresse ersetzt",
    "With the settings above, the app will create account settings in the following way:" : "Mit den obigen Einstellungen erstellt die App die Kontoeinstellungen wie folgt:",
    "S/MIME certificates" : "S/MIME Zertifikate",
    "Certificate name" : "Zertifikatsname",
    "E-mail address" : "E-Mail-Adresse",
    "Valid until" : "Gültig bis",
    "Delete certificate" : "Zertifikat löschen",
    "No certificate imported yet" : "Bislang wurde kein Zertifikat importiert",
    "Import certificate" : "Zertifikat importieren",
    "Import S/MIME certificate" : "S/MIME-Zertifikat importieren",
    "PKCS #12 Certificate" : "PKCS #12-Zertifikat",
    "PEM Certificate" : "PEM-Zertifikat",
    "Certificate" : "Zertifikat",
    "Private key (optional)" : "Privater Schlüssel (optional)",
    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Der private Schlüssel wird nur benötigt, wenn Du beabsichtigst, signierte und verschlüsselte E-Mails mit diesem Zertifikat zu versenden.",
    "Submit" : "Übermitteln",
    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "Das bereitgestellte PKCS #12-Zertifikat muss mindestens ein Zertifikat und genau einen privaten Schlüssel enthalten.",
    "Failed to import the certificate. Please check the password." : "Das Zertifikat konnte nicht importiert werden. Bitte überprüfe das Passwort.",
    "Certificate imported successfully" : "Zertifikat erfolgreich importiert",
    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Das Zertifikat konnte nicht importiert werden. Bitte stell sicher, dass der private Schlüssel zum Zertifikat passt und nicht durch eine Passphrase geschützt ist.",
    "Failed to import the certificate" : "Das Zertifikat konnte nicht importiert werden",
    "Keyboard shortcut" : "Tastaturkürzel",
    "Keyboard shortcuts" : "Tastaturkürzel",
    "Speed up your Mail experience with these quick shortcuts." : "Vereinfache deine Arbeit mit E-Mail durch diese Schnellbefehle.",
    "Compose new message" : "Neue Nachricht erstellen",
    "Newer message" : "Neuere Nachricht",
    "Older message" : "Ältere Nachricht",
    "Toggle star" : "Stern umschalten",
    "Toggle unread" : "Ungelesen umschalten",
    "Archive" : "Archivieren",
    "Account connected" : "Konto verbunden",
    "You can close this window" : "Du kannst dieses Fenster schließen.",
    "Connect your mail account" : "Verbinde dein E-Mail-Konto",
    "To add a mail account, please contact your administrator." : "Kontaktiere bitte deinen Administrator, um ein E-Mail-Konto hinzuzufügen.",
    "Tomorrow – {timeLocale}" : "Morgen – {timeLocale}",
    "Later today – {timeLocale}" : "Später am Tag – {timeLocale}",
    "Itinerary for {type} is not supported yet" : "Reiseroute für {type} wird noch nicht unterstützt",
    "All" : "Alle",
    "Drafts" : "Entwürfe",
    "Favorites" : "Favoriten",
    "Priority inbox" : "Vorrangiger Posteingang",
    "All inboxes" : "Alle Posteingänge",
    "Inbox" : "Posteingang",
    "Junk" : "Junk",
    "Sent" : "Gesendet",
    "Trash" : "Papierkorb",
    "Connect OAUTH2 account" : "OAUTH2-Konto verbinden",
    "Error while sharing file" : "Fehler beim Teilen der Datei",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n neue Nachricht\nvon {from}","%n neue Nachrichten\nvon {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "There is already a message in progress. All unsaved changes will be lost if you continue!" : "Es ist bereits eine Nachricht in Bearbeitung. Alle nicht gespeicherten Änderungen gehen verloren, wenn du fortfährst!",
    "Discard changes" : "Änderungen verwerfen",
    "Discard unsaved changes" : "Nicht gespeicherte Änderungen verwerfen",
    "Keep editing message" : "Nachricht weiter bearbeiten",
    "Attachments were not copied. Please add them manually." : "Anhänge konnten nicht kopiert werden. Bitte manuell hinzufügen.",
    "Could not create snooze mailbox" : "Das Zurückstellen-Postfach konnte nicht erstellt werden",
    "Message sent" : "Nachricht wurde gesendet",
    "Could not send message" : "Nachricht konnte nicht gelöscht werden",
    "Could not load {tag}{name}{endtag}" : "Konnte {tag}{name}{endtag} nicht laden",
    "There was a problem loading {tag}{name}{endtag}" : "Beim Laden von {tag}{name}{endtag} ist ein Problem aufgetreten",
    "Could not load your message" : "Deine Nachricht konnte nicht geladen werden",
    "Could not load the desired message" : "Gewünschte Nachricht konnte nicht geladen werden",
    "Could not load the message" : "Nachricht konnte nicht geladen werden",
    "Error loading message" : "Fehler beim Laden der Nachricht",
    "Forwarding to %s" : "Weiterleiten an %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klicke hier, wenn du nicht automatisch innerhalb der nächsten Sekunden weitergeleitet wirst.",
    "Redirect" : "Weiterleiten",
    "The link leads to %s" : "Der Link führt nach %s",
    "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Wenn du diese Seite nicht besuchen möchtest, kannst du zu <a href=\"%s\">Mail</a> zurückkehren",
    "Continue to %s" : "Weiter nach %s"
},
"nplurals=2; plural=(n != 1);");
